# CyyLog

![Version](https://img.shields.io/badge/version-0.0.4-green.svg?cacheSeconds=2592000)
![ProjectImage](https://raw.githubusercontent.com/ryyos/ryyos/refs/heads/main/images/erine/erine.jpg)

---

## Features ✨

- **informative log**: informative logs easy to understand and colorful
- **flexible storage**: storage with customizable keys
- **easy use**: Simple calls and easy setup

## Requirement ⚙️

- [click](https://pypi.org/project/click/) v8.1.8+

## Installation 🛠️

```sh
pip install cyylog
```
